==> apache-calcite-1.37.0-src.tar.gz: apache-calcite-1.37.0-src/testkit/src/main/java/org/apache/calcite/test/schemata/hr/Employee.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.calcite.test.schemata.hr;

import java.util.Objects;

/**
 * Employee model.
 */
public class Employee {
  public final int empid;
  public final int deptno;
  public final String name;
  public final float salary;
  public final Integer commission;

  public Employee(int empid, int deptno, String name, float salary,
      Integer commission) {
    this.empid = empid;
    this.deptno = deptno;
    this.name = name;
    this.salary = salary;
    this.commission = commission;
  }

  @Override public String toString() {
    return "Employee [empid: " + empid + ", deptno: " + deptno
        + ", name: " + name + "]";
  }

  @Override public boolean equals(Object obj) {
    return obj == this
        || obj instanceof Employee
        && empid == ((Employee) obj).empid;
  }

  @Override public int hashCode() {
    return Objects.hash(empid);
  }
}

==> apache-calcite-1.40.0-src.tar.gz: apache-calcite-1.40.0-src/testkit/src/main/java/org/apache/calcite/test/schemata/hr/Employee.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.calcite.test.schemata.hr;

import org.checkerframework.checker.nullness.qual.Nullable;

import java.util.Objects;

/**
 * Employee model.
 */
public class Employee {
  public final int empid;
  public final int deptno;
  public final String name;
  public final float salary;
  public final @Nullable Integer commission;

  public Employee(int empid, int deptno, String name, float salary,
      @Nullable Integer commission) {
    this.empid = empid;
    this.deptno = deptno;
    this.name = name;
    this.salary = salary;
    this.commission = commission;
  }

  @Override public String toString() {
    return "Employee [empid: " + empid + ", deptno: " + deptno
        + ", name: " + name + "]";
  }

  @Override public boolean equals(Object obj) {
    return obj == this
        || obj instanceof Employee
        && empid == ((Employee) obj).empid;
  }

  @Override public int hashCode() {
    return Objects.hash(empid);
  }
}
